Zhiyi Zhang : d3d8: Fix building on Mac.

Alexandre Julliard julliard at winehq.org
Wed May 15 14:32:22 CDT 2019


Module: wine
Branch: stable
Commit: d76718e438760a6f7bd7d56ca374b3fb89505ef6
URL:    https://source.winehq.org/git/wine.git/?a=commit;h=d76718e438760a6f7bd7d56ca374b3fb89505ef6

Author: Zhiyi Zhang <zzhang at codeweavers.com>
Date:   Wed Jan 30 22:25:07 2019 +0800

d3d8: Fix building on Mac.

bool is a reserved word in c99.

Signed-off-by: Zhiyi Zhang <zzhang at codeweavers.com>
Signed-off-by: Ken Thomases <ken at codeweavers.com>
Signed-off-by: Alexandre Julliard <julliard at winehq.org>
(cherry picked from commit 13cca44d20239612a23fa9b3fe51e072a2073a60)
Signed-off-by: Michael Stefaniuc <mstefani at winehq.org>

---

 dlls/d3d8/d3d8_main.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/dlls/d3d8/d3d8_main.c b/dlls/d3d8/d3d8_main.c
index 92c5032..6165971 100644
--- a/dlls/d3d8/d3d8_main.c
+++ b/dlls/d3d8/d3d8_main.c
@@ -60,16 +60,16 @@ IDirect3D8 * WINAPI DECLSPEC_HOTPATCH Direct3DCreate8(UINT sdk_version)
  *              ValidateVertexShader (D3D8.@)
  *
  * I've seen reserved1 and reserved2 always passed as 0's
  * bool seems always passed as 0 or 1, but other values work as well...
  * toto       result?
  */
-HRESULT WINAPI ValidateVertexShader(DWORD* vertexshader, DWORD* reserved1, DWORD* reserved2, BOOL bool, DWORD* toto)
+HRESULT WINAPI ValidateVertexShader(DWORD* vertexshader, DWORD* reserved1, DWORD* reserved2, BOOL boolean, DWORD* toto)
 {
   HRESULT ret;
   static BOOL warned;
 
   if (TRACE_ON(d3d8) || !warned) {
-      FIXME("(%p %p %p %d %p): stub\n", vertexshader, reserved1, reserved2, bool, toto);
+      FIXME("(%p %p %p %d %p): stub\n", vertexshader, reserved1, reserved2, boolean, toto);
       warned = TRUE;
   }
 
@@ -98,13 +98,13 @@ HRESULT WINAPI ValidateVertexShader(DWORD* vertexshader, DWORD* reserved1, DWORD
  * PARAMS
  * toto       result?
  */
-HRESULT WINAPI ValidatePixelShader(DWORD* pixelshader, DWORD* reserved1, BOOL bool, DWORD* toto)
+HRESULT WINAPI ValidatePixelShader(DWORD* pixelshader, DWORD* reserved1, BOOL boolean, DWORD* toto)
 {
   HRESULT ret;
   static BOOL warned;
 
   if (TRACE_ON(d3d8) || !warned) {
-      FIXME("(%p %p %d %p): stub\n", pixelshader, reserved1, bool, toto);
+      FIXME("(%p %p %d %p): stub\n", pixelshader, reserved1, boolean, toto);
       warned = TRUE;
   }
 
@@ -60,16 +60,16 @@ IDirect3D8 * WINAPI DECLSPEC_HOTPATCH Direct3DCreate8(UINT sdk_version)
  *
  * I've seen reserved1 and reserved2 always passed as 0's
- * bool seems always passed as 0 or 1, but other values work as well...
+ * boolean seems always passed as 0 or 1, but other values work as well...
  * toto       result?
  */




More information about the wine-cvs mailing list